var OS_IOS = Ti.Platform.name === 'iPhone OS';
var OS_ANDROID = !OS_IOS;
var TOP = (OS_IOS && parseInt(Ti.Platform.version[0], 10) >= 7) ? 20 : 0;

var Compression = require('ti.compression');

var source = Ti.Filesystem.resourcesDirectory + 'test.zip';

// on Android: "app://"
console.debug('resourcesDirectory: ' + Ti.Filesystem.resourcesDirectory);

Compression.unzip(Ti.Filesystem.applicationDataDirectory, source, true);

// on Android: "appdata-private://"
console.debug('applicationDataDirectory: ' + Ti.Filesystem.applicationDataDirectory);

Compression.unzip(Ti.Filesystem.applicationSupportDirectory, source, true);

if (Ti.Filesystem.isExternalStoragePresent()) {

  // on Android: "appdata://"
  console.debug('externalStorageDirectory: ' + Ti.Filesystem.externalStorageDirectory);

  Compression.unzip(Ti.Filesystem.externalStorageDirectory, source, true);
}

var win = Ti.UI.createWindow({
  backgroundColor: 'white'
});

var table = Ti.UI.createTableView({
  top: TOP,
  data: [{
    title: 'url remote',
    color: 'green',
  }, {
    title: 'url resourcesDirectory',
    color: 'green',
  }, {
    title: 'html resourcesDirectory',
    color: 'green',
  }, {
    title: 'setHtml resourcesDirectory',
    color: 'green',
  }, {
    title: 'url applicationDataDirectory',
    color: OS_ANDROID ? 'red' : 'green',
  }, {
    title: 'html applicationDataDirectory',
    color: OS_ANDROID ? 'red' : 'green',
  }, {
    title: 'setHtml applicationDataDirectory',
    color: OS_ANDROID ? 'red' : 'green',
  }, {
    title: 'url applicationSupportDirectory',
    color: OS_ANDROID ? 'black' : 'green',
  }, {
    title: 'html applicationSupportDirectory',
    color: OS_ANDROID ? 'black' : 'green',
  }, {
    title: 'setHtml applicationSupportDirectory',
    color: OS_ANDROID ? 'black' : 'green',
  }, {
    title: 'url externalStorageDirectory',
    color: OS_ANDROID ? 'red' : 'black',
  }, {
    title: 'html externalStorageDirectory',
    color: OS_ANDROID ? 'red' : 'black',
  }, {
    title: 'setHtml externalStorageDirectory',
    color: OS_ANDROID ? 'red' : 'black',
  }]
});

table.addEventListener('click', function(e) {
  var data = e.rowData;

  if (data.title.match(/externalStorageDirectory/) && !Ti.Filesystem.isExternalStoragePresent()) {
    alert('No external storage found');
    return;
  }

  if (OS_ANDROID && data.title.match(/applicationSupportDirectory/)) {
    alert('No applicationSupportDirectory on Android');
    return;
  }

  var testWindow = Ti.UI.createWindow({
    backgroundColor: 'white'
  });

  var label = Ti.UI.createLabel({
    top: TOP,
    width: Ti.UI.FILL,
    height: 44,
    backgroundColor: 'black',
    color: 'white',
    textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
    text: data.title + ' (close)'
  });

  label.addEventListener('click', function(e) {

    if (OS_ANDROID) {
      webview.release();
    }

    testWindow.close();
  });

  var webview = Ti.UI.createWebView({
    top: TOP + 44
  });

  function getHtml(path) {
    path = path || '';
    return '<html><head><link rel="stylesheet" href="' + path + 'test.css" /></head><body>this should be green and you should see alert<script type="text/javascript" src="' + path + 'test.js"></script></body></html>';
  }

  switch (data.title) {

    case 'url remote':

      webview.url = 'http://www.appcelerator.com';

      break;

    case 'url resourcesDirectory':

      webview.url = 'test.html';

      break;

    case 'url applicationDataDirectory':

      webview.url = Ti.Filesystem.applicationDataDirectory + 'test.html';

      break;

    case 'url applicationSupportDirectory':

      webview.url = Ti.Filesystem.applicationSupportDirectory + 'test.html';

      break;

    case 'url externalStorageDirectory':

      webview.url = Ti.Filesystem.externalStorageDirectory + 'test.html';

      break;

    case 'html resourcesDirectory':

      webview.html = getHtml();

      break;

    case 'setHtml resourcesDirectory':

      webview.setHtml(getHtml(), {
        baseURL: OS_ANDROID ? 'file:///android_asset/Resources/' : Ti.Filesystem.resourcesDirectory
      });

      break;

    case 'html applicationDataDirectory':

      webview.html = getHtml(Ti.Filesystem.applicationDataDirectory);

      break;

    case 'setHtml applicationDataDirectory':

      webview.setHtml(getHtml(), {
        baseURL: Ti.Filesystem.applicationDataDirectory
      });

      break;

    case 'html applicationSupportDirectory':

      webview.html = getHtml(Ti.Filesystem.applicationSupportDirectory);

      break;

    case 'setHtml applicationSupportDirectory':

      webview.setHtml(getHtml(), {
        baseURL: Ti.Filesystem.applicationSupportDirectory
      });

      break;

    case 'html externalStorageDirectory':

      webview.html = getHtml(Ti.Filesystem.externalStorageDirectory);

      break;

    case 'setHtml externalStorageDirectory':

      webview.setHtml(getHtml(), {
        baseURL: Ti.Filesystem.externalStorageDirectory
      });

      break;

  }

  testWindow.add(label);
  testWindow.add(webview);

  testWindow.open();
});

win.add(table);

win.open();